@@ -3,13 +3,14 @@ import logging
 import time
 
 from .event_handler import EventHandler
-from .rustplus_pb2 import *
-from .rustws import RustWebsocket
+from .rustplus_proto import *
+from .rustws import RustWebsocket, CONNECTED, PENDING_CONNECTION
 from .token_bucket import RateLimiter
+from .expo_bundle_handler import MagicValueGrabber
 from ...commands import CommandHandler
 from ...exceptions import (
     ClientNotConnectedError,
-    ResponseNotRecievedError,
+    ResponseNotReceivedError,
     RequestError,
 )
 from ...utils import RegisteredListener
@@ -37,11 +38,10 @@ class RustRemote:
             ratelimit_limit, ratelimit_limit, 1, ratelimit_refill
         )
         self.ws = None
-        self.is_pending = False
         self.websocket_length = websocket_length
         self.responses = {}
         self.ignored_responses = []
-        self.pending_requests = {}
+        self.pending_for_response = {}
         self.sent_requests = []
 
         if command_options is None:
@@ -53,12 +53,14 @@ class RustRemote:
 
         self.event_handler = EventHandler()
 
-    def connect(self, retries) -> None:
+        self.magic_value = MagicValueGrabber.get_magic_value()
+
+    def connect(self, retries, delay) -> None:
 
         self.ws = RustWebsocket(
-            ip=self.ip, port=self.port, remote=self, use_proxy=self.use_proxy
+            ip=self.ip, port=self.port, remote=self, use_proxy=self.use_proxy, magic_value=self.magic_value
         )
-        self.ws.connect(retries=retries)
+        self.ws.connect(retries=retries, delay=delay)
 
     def close(self) -> None:
 
@@ -67,18 +69,30 @@ class RustRemote:
             del self.ws
             self.ws = None
 
+    def is_pending(self) -> bool:
+        if self.ws is not None:
+            return self.ws.connection_status == PENDING_CONNECTION
+        return False
+
+    def is_open(self) -> bool:
+        if self.ws is not None:
+            return self.ws.connection_status == CONNECTED
+        return False
+
     async def send_message(self, request: AppRequest) -> None:
 
-        self.ws.send_message(request)
+        await self.ws.send_message(request)
 
-    async def get_response(self, seq: int, app_request: AppRequest) -> AppMessage:
+    async def get_response(
+        self, seq: int, app_request: AppRequest, error_check: bool = True
+    ) -> AppMessage:
         """
         Returns a given response from the server.
         """
 
         attempts = 0
 
-        while seq in self.pending_requests:
+        while seq in self.pending_for_response and seq not in self.responses:
 
             if seq in self.sent_requests:
 
@@ -90,7 +104,7 @@ class RustRemote:
                 else:
 
                     await self.send_message(app_request)
-                    await asyncio.sleep(1)
+                    await asyncio.sleep(0.1)
                     attempts = 0
 
             if attempts <= 10:
@@ -103,7 +117,7 @@ class RustRemote:
                 attempts = 0
 
         if seq not in self.responses:
-            raise ResponseNotRecievedError("Not Recieved")
+            raise ResponseNotReceivedError("Not Received")
 
         response = self.responses.pop(seq)
 
@@ -122,7 +136,7 @@ class RustRemote:
                 self.ratelimiter.bucket.refresh()
 
             # Reattempt the sending with a full bucket
-            cost = self.ws._get_proto_cost(app_request)
+            cost = self.ws.get_proto_cost(app_request)
 
             while True:
 
@@ -135,7 +149,7 @@ class RustRemote:
             await self.send_message(app_request)
             response = await self.get_response(seq, app_request)
 
-        elif self.ws.error_present(response.response.error.error):
+        elif self.ws.error_present(response.response.error.error) and error_check:
             raise RequestError(response.response.error.error)
 
         return response
@@ -145,12 +159,12 @@ class RustRemote:
         if self.ws is None:
             raise ClientNotConnectedError("No Current Websocket Connection")
 
-        while self.is_pending:
+        while self.is_pending():
             time.sleep(1)
 
         if time.time() - self.ws.connected_time >= self.websocket_length:
             self.close()
-            self.connect(retries=retries)
+            self.connect(retries=retries, delay=20)
 
         return self.ws
 
